@@ -1,4 +1,4 @@
-FKM.gkb.noise <- function (X, k, m, vp, delta, gam, mcn, RS, stand, startU, index,alpha,conv, maxit, seed)
+FKM.gkb.noise <- function (X, k, m, vp, delta, gam, mcn, RS, stand, startU, index,alpha,conv, maxit, seed = NULL)
   {
     if (missing(X))
       stop("The data set must be given")
@@ -365,23 +365,17 @@ FKM.gkb.noise <- function (X, k, m, vp, delta, gam, mcn, RS, stand, startU, inde
       cat("The maximum number of iterations maxit must be an integer >0: the value ceiling(maxit) will be used ",fill=TRUE)
       maxit=ceiling(maxit)
     }
-    if (missing(seed))
-      set.seed(NULL)
-    else
+
+    if(!is.null(seed))
     {
       if (!is.numeric(seed))
       {
         cat("The seed value is not numeric: set.seed(NULL) will be used ",fill=TRUE)
         set.seed(NULL)
-      }else
-      {
-        if (seed%%ceiling(seed)>0)
-        {
-          cat("The seed value must be an integer: set.seed(ceiling(seed)) will be used ",fill=TRUE)
-          set.seed(ceiling(seed))
-        }else
-          set.seed(seed)
+      }else{
+        set.seed(seed)
       }
+
     }
 
     Xraw=X
@@ -459,7 +453,7 @@ FKM.gkb.noise <- function (X, k, m, vp, delta, gam, mcn, RS, stand, startU, inde
       {
         Hd=FKM.gkb(X,k[c],m = m,RS=1,stand = stand,conv=1e-6,seed = seed)$H
         Dd = euclidean_distance(data = X,H = Hd,n = n,k = k[c])
-        delta[c] <- mean(Dd)
+        delta[c] <- sqrt(mean(Dd))
       }
       main.temp <- mainFKM_gkb_noise_U(data = X, m = m,delta = delta[c], index = index,alpha = alpha,
                                        n = n, p = p, k = k[c], U = startU, conv = conv,
@@ -471,7 +465,7 @@ FKM.gkb.noise <- function (X, k, m, vp, delta, gam, mcn, RS, stand, startU, inde
       {
         Hd=FKM.gkb(X,k[c],m = m,RS=1,stand = stand,conv=1e-6,seed = seed)$H
         Dd = euclidean_distance(data = X,H = Hd,n = n,k = k[c])
-        delta[c] <- mean(Dd)
+        delta[c] <- sqrt(mean(Dd))
       }
       main.temp <- mainFKM_gkb_noise(data = X, m = m, delta = delta[c], index = index,alpha = alpha,
                                      n = n, p = p, k = k[c], rs = RS, conv = conv,
