@@ -1,5 +1,5 @@
 FKM.noise <-
-  function (X, k, m, delta, RS, stand, startU, index,alpha,conv, maxit, seed)
+  function (X, k, m, delta, RS, stand, startU, index,alpha,conv, maxit, seed = NULL)
   {
     if (missing(X))
       stop("The data set must be given")
@@ -294,23 +294,17 @@ FKM.noise <-
       stand=0
     if (!is.numeric(stand))
       stand=0
-    if (missing(seed))
-      {set.seed(NULL)}
-    else
+
+    if(!is.null(seed))
     {
       if (!is.numeric(seed))
       {
         cat("The seed value is not numeric: set.seed(NULL) will be used ",fill=TRUE)
         set.seed(NULL)
-      }else
-      {
-        if (seed%%ceiling(seed)>0)
-        {
-          cat("The seed value must be an integer: set.seed(ceiling(seed)) will be used ",fill=TRUE)
-          set.seed(ceiling(seed))
-        }else
-          set.seed(seed)
+      }else{
+        set.seed(seed)
       }
+
     }
 
     Xraw=X
@@ -384,7 +378,7 @@ FKM.noise <-
       {
         Hd=FKM(X,k[c],m = m,RS=1,stand = stand,conv=1e-6,seed = seed)$H
         Dd = euclidean_distance(data = X,H = Hd,n = n,k = k[c])
-        delta[c] <- mean(Dd)
+        delta[c] <- sqrt(mean(Dd))
       }
       main.temp <- mainFKM_noise_U(data = X, m = m, delta = delta[c], index = index,
                                    alpha = alpha,n = n, p = p, k = k[c],
@@ -395,7 +389,7 @@ FKM.noise <-
       {
         Hd=FKM(X,k[c],m = m,RS=1,stand = stand,conv=1e-6, seed = seed)$H
         Dd = euclidean_distance(data = X,H = Hd,n = n,k = k[c])
-        delta[c] <- mean(Dd)
+        delta[c] <- sqrt(mean(Dd))
       }
       main.temp <- mainFKM_noise(data = X, m = m, delta = delta[c], index = index,alpha = alpha,
                                  n = n, p = p, k = k[c], rs = RS, conv = conv, maxit = maxit)
